@@ -4,9 +4,10 @@ from typing import Any
 
 from airflow.decorators.base import get_unique_task_id
 from airflow.models.xcom_arg import XComArg
+
 from astro.databases import create_database
 from astro.sql.operators.base_operator import AstroSQLBaseOperator
-from astro.sql.table import BaseTable
+from astro.table import BaseTable
 from astro.utils.typing_compat import Context
 
 
@@ -30,7 +31,7 @@ class DropTableOperator(AstroSQLBaseOperator):
 
     def execute(self, context: Context) -> BaseTable:  # skipcq: PYL-W0613
         """Method run when the Airflow runner calls the operator."""
-        database = create_database(self.table.conn_id)
+        database = create_database(self.table.conn_id, table=self.table)
         self.table = database.populate_table_metadata(self.table)
         database.drop_table(self.table)
         return self.table
